==> ginkgo-1.4.0.tar.gz: ginkgo-1.4.0/core/test/utils/array_generator.hpp <==
/*******************************<GINKGO LICENSE>******************************
Copyright (c) 2017-2021, the Ginkgo authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
******************************<GINKGO LICENSE>*******************************/

#ifndef GKO_CORE_TEST_UTILS_ARRAY_GENERATOR_HPP_
#define GKO_CORE_TEST_UTILS_ARRAY_GENERATOR_HPP_


#include <ginkgo/core/base/array.hpp>
#include <ginkgo/core/base/math.hpp>
#include <ginkgo/core/base/utils.hpp>


#include "core/test/utils/value_generator.hpp"


namespace gko {
namespace test {


/**
 * Generate a random array
 *
 * @tparam ValueType  valuetype of the array to generate
 * @tparam ValueDistribution  type of value distribution
 * @tparam Engine  type of random engine
 *
 * @param num  the number of elements of array
 * @param value_dist  distribution of array values
 * @param engine  a random engine
 * @param exec  executor where the array should be allocated
 *
 * @return Array<ValueType>
 */
template <typename ValueType, typename ValueDistribution, typename Engine>
Array<ValueType> generate_random_array(size_type num,
                                       ValueDistribution &&value_dist,
                                       Engine &&engine,
                                       std::shared_ptr<const Executor> exec)
{
    Array<ValueType> array(exec->get_master(), num);
    auto val = array.get_data();
    for (int i = 0; i < num; i++) {
        val[i] = detail::get_rand_value<ValueType>(value_dist, engine);
    }
    array.set_executor(exec);
    return array;
}


}  // namespace test
}  // namespace gko


#endif  // GKO_CORE_TEST_UTILS_ARRAY_GENERATOR_HPP_

==> ginkgo-1.6.0.tar.gz: ginkgo-1.6.0/core/test/utils/array_generator.hpp <==
/*******************************<GINKGO LICENSE>******************************
Copyright (c) 2017-2023, the Ginkgo authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
******************************<GINKGO LICENSE>*******************************/

#ifndef GKO_CORE_TEST_UTILS_ARRAY_GENERATOR_HPP_
#define GKO_CORE_TEST_UTILS_ARRAY_GENERATOR_HPP_


#include <ginkgo/core/base/array.hpp>
#include <ginkgo/core/base/math.hpp>
#include <ginkgo/core/base/utils.hpp>


#include "core/test/utils/value_generator.hpp"


namespace gko {
namespace test {


/**
 * Generate a random array
 *
 * @tparam ValueType  valuetype of the array to generate
 * @tparam ValueDistribution  type of value distribution
 * @tparam Engine  type of random engine
 *
 * @param num  the number of elements of array
 * @param value_dist  distribution of array values
 * @param engine  a random engine
 * @param exec  executor where the array should be allocated
 *
 * @return array<ValueType>
 */
template <typename ValueType, typename ValueDistribution, typename Engine>
array<ValueType> generate_random_array(size_type num,
                                       ValueDistribution&& value_dist,
                                       Engine&& engine,
                                       std::shared_ptr<const Executor> exec)
{
    array<ValueType> array(exec->get_master(), num);
    auto val = array.get_data();
    for (int i = 0; i < num; i++) {
        val[i] = detail::get_rand_value<ValueType>(value_dist, engine);
    }
    array.set_executor(exec);
    return array;
}


}  // namespace test
}  // namespace gko


#endif  // GKO_CORE_TEST_UTILS_ARRAY_GENERATOR_HPP_
